@@ -4,13 +4,13 @@ from typing import Callable
 from typing import Dict
 from typing import Union
 
-from . import HttpResponse
-from .application import http
+from .application import HttpApplication
 from .http_error import HttpError
 from .http_headers import HttpHeaders
 from .http_method import HttpMethod
 from .http_query_string import HttpQueryString
 from .http_request import HttpRequest
+from .http_response import HttpResponse
 from .middleware import Middleware
 from .middleware import MiddlewarePipeline
 from .router_middleware import RouterMiddleware
@@ -33,7 +33,7 @@ def create_http_request_from_wsgi(environ: Dict[str, Any]) -> HttpRequest:
     )
 
 
-def create_wsgi_handler(*middleware: Union[Callable, Middleware], debug: bool = False) -> Callable[[Dict[str, Any]], Callable]:
+def create_wsgi_handler(application: HttpApplication, *middleware: Union[Callable, Middleware], debug: bool = False) -> Callable[[Dict[str, Any]], Callable]:
 
     def _handler(environ: Dict[str, Any], start: Callable) -> bytes:
         # Prepare pipeline
@@ -41,7 +41,7 @@ def create_wsgi_handler(*middleware: Union[Callable, Middleware], debug: bool =
         for item in middleware:
             middleware_pipeline.append(item)
 
-        middleware_pipeline.append(RouterMiddleware.from_http_application(http))
+        middleware_pipeline.append(RouterMiddleware.from_http_application(application))
 
         request = create_http_request_from_wsgi(environ)
 
@@ -70,9 +70,9 @@ def create_wsgi_handler(*middleware: Union[Callable, Middleware], debug: bool =
     return _handler
 
 
-def serve(*middleware: Union[Callable, Middleware], host: str = "127.0.0.1", port=80, debug: bool = False) -> None:
+def serve(application: HttpApplication, *middleware: Union[Callable, Middleware], host: str = "127.0.0.1", port=80, debug: bool = False) -> None:
     import bjoern
 
-    wsgi_handler = create_wsgi_handler(*middleware, debug=debug)
+    wsgi_handler = create_wsgi_handler(application, *middleware, debug=debug)
 
     bjoern.run(wsgi_handler, host, port)
